@@ -8,9 +8,11 @@
 
 """sampler objects"""
 
-__all__ = ["Integrator", "IntegratorDS", "ZonalIntegrator", "ZonalIntegratorDS"]
+__all__ = ["Integrator", "IntegratorDS", "ZonalIntegrator", "ZonalIntegratorDS",
+           "IntegratorDV"]
 
 from raytraverse.integrator.integrator import Integrator
 from raytraverse.integrator.integratords import IntegratorDS
 from raytraverse.integrator.zonalintegrator import ZonalIntegrator
 from raytraverse.integrator.zonalintegratords import ZonalIntegratorDS
+from raytraverse.integrator.integratordv import IntegratorDV
