@@ -8,8 +8,12 @@
 
 """mapper objects"""
 
-__all__ = ['SpaceMapper', 'ViewMapper', 'SpaceMapperPt']
+__all__ = ['Mapper', 'PlanMapper', 'MaskedPlanMapper', 'ViewMapper', 'SkyMapper']
 
+from raytraverse.mapper.mapper import Mapper
 from raytraverse.mapper.viewmapper import ViewMapper
-from raytraverse.mapper.spacemapper import SpaceMapper
-from raytraverse.mapper.spacemapperpt import SpaceMapperPt
+from raytraverse.mapper.planmapper import PlanMapper
+from raytraverse.mapper.maskedplanmapper import MaskedPlanMapper
+from raytraverse.mapper.skymapper import SkyMapper
+
+
