@@ -10,7 +10,7 @@
 
 __all__ = ['BaseSampler', 'SamplerArea', 'SamplerSuns', 'SamplerPt',
            'SkySamplerPt', 'SunSamplerPtView', 'SunSamplerPt', 'ImageSampler',
-           'DeterministicImageSampler']
+           'DeterministicImageSampler', 'SrcSamplerPt']
 
 from raytraverse.sampler.basesampler import BaseSampler
 from raytraverse.sampler.samplerarea import SamplerArea
@@ -18,6 +18,7 @@ from raytraverse.sampler.samplersuns import SamplerSuns
 from raytraverse.sampler.samplerpt import SamplerPt
 from raytraverse.sampler.sunsamplerptview import SunSamplerPtView
 from raytraverse.sampler.sunsamplerpt import SunSamplerPt
+from raytraverse.sampler.srcsamplerpt import SrcSamplerPt
 from raytraverse.sampler.skysamplerpt import SkySamplerPt
 from raytraverse.sampler.imagesampler import ImageSampler
 from raytraverse.sampler.imagesampler import DeterministicImageSampler
