@@ -10,7 +10,7 @@
 """functions for translating between coordinate spaces and resolutions"""
 
 import numpy as np
-from scipy.ndimage.filters import gaussian_filter, uniform_filter
+from scipy.ndimage import gaussian_filter, uniform_filter
 from scipy.spatial import cKDTree
 
 
@@ -446,7 +446,7 @@ def rmtx_yp(v):
     -----
     if N is one:
     Forward: (pmtx@(ymtx@xyz.T)).T or np.einsum("ij,kj,li->kl", ymtx, xyz, pmtx)
-    Backward: (ymtx.T@(pmtx.T@xyz.T)).T or np.einsum("ji,kj,il-vkl", pmtx, nv, ymtx)
+    Backward: (ymtx.T@(pmtx.T@xyz.T)).T or np.einsum("ji,kj,il-kl", pmtx, nv, ymtx)
     else:
     Forward: np.einsum("vij,vkj,vli->vkl", ymtx, xyz, pmtx)
     Backward: np.einsum("vji,vkj,vil-vkl", pmtx, nv, ymtx)
@@ -514,3 +514,11 @@ def cull_vectors(vecs, tol):
             flt[q] = False
             flagged.update(q)
     return flt
+
+
+def reflect(ray, normal, returnmasked=False):
+    refl = ray - 2 * normal * np.einsum("ij,kj->ik", ray, normal)
+    n = np.isclose(np.linalg.norm(refl, axis=-1), 1)
+    if returnmasked:
+        return refl[n]
+    return refl, n
